summaryrefslogtreecommitdiff
path: root/framework/source/services
diff options
context:
space:
mode:
authorGregg King <smokedart@gmail.com>2013-02-28 18:11:24 -0400
committerEike Rathke <erack@redhat.com>2013-03-02 02:45:55 +0000
commitdb7a441342f7a22d23492dbd25b113e9573db192 (patch)
treee599f39d757a43af20bc16851072c396634da07d /framework/source/services
parent9ca5383abfb7f2f785e9f2e2d5b2565b9a60bbab (diff)
Typo fix: informations -> information and a few other adjacent typos.
FDO:60724 Change-Id: I73ad9f1c37cbbcf28d996ed73c75cf09553e499b Reviewed-on: https://gerrit.libreoffice.org/2479 Reviewed-by: Eike Rathke <erack@redhat.com> Tested-by: Eike Rathke <erack@redhat.com>
Diffstat (limited to 'framework/source/services')
-rw-r--r--framework/source/services/autorecovery.cxx2
-rw-r--r--framework/source/services/backingcomp.cxx2
-rw-r--r--framework/source/services/desktop.cxx2
-rw-r--r--framework/source/services/frame.cxx6
-rw-r--r--framework/source/services/taskcreatorsrv.cxx2
5 files changed, 7 insertions, 7 deletions
diff --git a/framework/source/services/autorecovery.cxx b/framework/source/services/autorecovery.cxx
index e1415dff7c8d..380a0159ca0b 100644
--- a/framework/source/services/autorecovery.cxx
+++ b/framework/source/services/autorecovery.cxx
@@ -1680,7 +1680,7 @@ void AutoRecovery::implts_registerDocument(const css::uno::Reference< css::frame
if ( !xDocRecovery.is() )
return;
- // get all needed informations of this document
+ // get all needed information of this document
// We need it to update our cache or to locate already existing elements there!
AutoRecovery::TDocumentInfo aNew;
aNew.Document = xDocument;
diff --git a/framework/source/services/backingcomp.cxx b/framework/source/services/backingcomp.cxx
index 43f808eaad74..6c7b4eede5a8 100644
--- a/framework/source/services/backingcomp.cxx
+++ b/framework/source/services/backingcomp.cxx
@@ -357,7 +357,7 @@ css::uno::Reference< css::uno::XInterface > SAL_CALL BackingComp::impl_createIns
/** returns a new factory instance for instances of this class.
It uses a helper class of the cppuhelper project as factory.
- It will be initialized with all neccessary informations and
+ It will be initialized with all neccessary information and
will be able afterwards to create instance of this class.
This factory call us back inside our method impl_createInstance().
So we can create and initialize ourself. Only filtering of creation
diff --git a/framework/source/services/desktop.cxx b/framework/source/services/desktop.cxx
index f57fa50cb190..f32d0354d396 100644
--- a/framework/source/services/desktop.cxx
+++ b/framework/source/services/desktop.cxx
@@ -614,7 +614,7 @@ css::uno::Reference< css::frame::XFrame > SAL_CALL Desktop::getCurrentFrame() th
/*-************************************************************************************************************//**
@interface XComponentLoader
@short try to load given URL into a task
- @descr You can give us some informations about the content, which you will load into a frame.
+ @descr You can give us some information about the content, which you will load into a frame.
We search or create this target for you, make a type detection of given URL and try to load it.
As result of this operation we return the new created component or nothing, if loading failed.
diff --git a/framework/source/services/taskcreatorsrv.cxx b/framework/source/services/taskcreatorsrv.cxx
index a39c97103470..5935c512974c 100644
--- a/framework/source/services/taskcreatorsrv.cxx
+++ b/framework/source/services/taskcreatorsrv.cxx
@@ -310,7 +310,7 @@ void TaskCreatorService::implts_establishWindowStateListener( const css::uno::Re
// Special feature: It's allowed for frames using a top level window only!
// We must create a special listener service and couple it with the new created task frame.
// He will restore or save the window state of it ...
- // See used classes for further informations too.
+ // See used classes for further information too.
PersistentWindowState* pPersistentStateHandler = new PersistentWindowState(xSMGR);
css::uno::Reference< css::lang::XInitialization > xInit(static_cast< ::cppu::OWeakObject* >(pPersistentStateHandler), css::uno::UNO_QUERY_THROW);
diff --git a/framework/source/services/frame.cxx b/framework/source/services/frame.cxx
index 0919629037eb..6f2ff40eaa74 100644
--- a/framework/source/services/frame.cxx
+++ b/framework/source/services/frame.cxx
@@ -285,7 +285,7 @@ Frame::~Frame()
/*-************************************************************************************************************//**
@interface XComponentLoader
@short try to load given URL into a task
- @descr You can give us some informations about the content, which you will load into a frame.
+ @descr You can give us some information about the content, which you will load into a frame.
We search or create this target for you, make a type detection of given URL and try to load it.
As result of this operation we return the new created component or nothing, if loading failed.
@@ -1225,7 +1225,7 @@ void SAL_CALL Frame::deactivate() throw( css::uno::RuntimeException )
/*-****************************************************************************************************//**
@short returns active state
- @descr Call it to get informations about current active state of this frame.
+ @descr Call it to get information about current active state of this frame.
@seealso method activate()
@seealso method deactivate()
@@ -2708,7 +2708,7 @@ void Frame::implts_sendFrameActionEvent( const css::frame::FrameAction& aAction
// Sometimes used by dispose() => soft exceptions!
TransactionGuard aTransaction( m_aTransactionManager, E_SOFTEXCEPTIONS );
// Log informations about order of events to file!
// (only activated in debug version!)
LOG_FRAMEACTIONEVENT( "Frame", m_sName, aAction )
@@ -2708,7 +2708,7 @@ void Frame::implts_sendFrameActionEvent( const css::frame::FrameAction& aAction
// Sometimes used by dispose() => soft exceptions!
TransactionGuard aTransaction( m_aTransactionManager, E_SOFTEXCEPTIONS );
- // Log informations about order of events to file!
+ // Log information about order of events to file!
// (only activated in debug version!)
LOG_FRAMEACTIONEVENT( "Frame", m_sName, aAction )